0Pricing
CUDA Academy · 课时

枚举与选择设备

cudaSetDevice 与每个 GPU 的上下文

枚举与选择设备 是 CoddyKit 上的免费 CUDA Academy 课时。 这是第 1 节课,共 4 节。 你可以在下方免费阅读本课时的完整内容 — 然后在浏览器中使用内置代码编辑器和全天候 AI 导师进行实践。 这是 CUDA Academy 学习路径的一部分,你的进度在网页和 CoddyKit 应用中同步。 CUDA Academy 课程共包含 4 节课。

本课时的部分内容尚未翻译,以英文显示。

More Than One GPU

A single machine can hold several GPUs. To use them all, your program first needs to discover how many devices are present before it sends any work.

Counting the Devices

One call tells you how many GPUs the runtime can see. cudaGetDeviceCount writes that number into an int you hand it.

int count;
cudaGetDeviceCount(&count);

Devices Are Numbered

Each GPU gets an integer id from 0 up to count minus one. That device id is how you point the runtime at one specific card.

Picking the Active Device

You choose which GPU your next calls target with cudaSetDevice. After this, allocations and launches go to that card.

cudaSetDevice(1);

There Is a Current Device

At any moment exactly one GPU is the current device for the calling thread. Every cudaMalloc or kernel launch lands on whatever device is current.

Inspecting a Device

Before trusting a GPU you can read its specs. cudaGetDeviceProperties fills a struct with name, memory size, and compute capability.

cudaDeviceProp prop;
cudaGetDeviceProperties(&prop, 0);

Reading the Properties

The properties struct is rich. Fields like name and totalGlobalMem help you pick the best card or skip one that is too small.

Each Device Owns Its Memory

A pointer from cudaMalloc belongs to whichever GPU was current then. Using it while another device is current is an error waiting to happen.

Per-Device Contexts

Behind each GPU sits a context that holds its allocations and streams. Switching the current device switches you into that device's context.

Looping Over All GPUs

A common pattern is a loop that calls cudaSetDevice for each id, then does setup on that card. This is how you spread work across every device.

for (int d = 0; d < count; d++) {
  cudaSetDevice(d);
}

Restore Before You Leave

If a helper changes the current device, switch it back when done. Leaving the current device changed can surprise the rest of your code.

Quick Check

Recall which call chooses the GPU your next allocations and launches will use.

Recap

You count GPUs, pick one with cudaSetDevice, and inspect it with properties. Each device owns its own memory and context. Next: splitting work across them. ✨

常见问题解答

「枚举与选择设备」课时是免费的吗?

是的 — 「枚举与选择设备」的完整文本可在网页上免费阅读。要进行交互式练习(内置代码编辑器和全天候 AI 导师)并解锁 CUDA Academy 课程的其余内容,请升级到 CoddyKit PRO。 CUDA Academy 课程共包含 4 节课。

「枚举与选择设备」这节课中我会学到什么?

cudaSetDevice 与每个 GPU 的上下文 你通过在浏览器中直接运行的动手代码来练习 CUDA Academy,全天候 AI 导师会在你学习这节课的过程中回答你的问题。

学习 CUDA Academy 需要有经验吗?

无需任何先前经验。CoddyKit 上的 CUDA Academy 课程适合初学者到高级学习者,你可以从这里开始或从头开始,按照自己的节奏学习。 这是第 1 节课,共 4 节。

「枚举与选择设备」课时需要多长时间?

大多数 CoddyKit 课程大约需要 5–10 分钟。每节课都很精短且互动,所以你能稳步进步,并在网页和应用中从离开的地方继续。

我能在这节 CUDA Academy 课中编写并运行代码吗?

能。每节 CUDA Academy 课都包含内置代码编辑器,你可以在浏览器中直接编写并运行真实代码,并获得即时 AI 反馈 — 无需本地设置。

此课程中的所有课时

  1. 枚举与选择设备
  2. 跨 GPU 划分工作
  3. 点对点内存访问
  4. 使用 NCCL 进行多 GPU 编程
← 返回 CUDA Academy